pub struct RaftProcess { /* private fields */ }Expand description
RaftProcess is a implementation of Raft process in RaftNode.
RaftProcess is unaware of the gRPC and the network but just focuses on the Raft algorithm.
Implementations
Sourceimpl RaftProcess
impl RaftProcess
pub async fn new( app: impl RaftApp, log_store: impl RaftLogStore, ballot_store: impl RaftBallotStore, driver: RaftDriver, ) -> Result<Self>